NORMAL_COLOR = 'NONE'
ORANGE =  'rgb(255,84,0)'
ORANGE_NUM = (255,84,0)

TEAL = 'rgb(0,255,236)'
TEAL_NUM = (0,255,236)

GREEN = 'rgb(0,255,0)'
GREEN_NUM = (0,255,0)

PURPLE = 'rgb(88,80,192)'
PURPLE_NUM = (88,80,192)

YELLOW = 'rgb(221,213,51)'
YELLOW_NUM = (221,213,51)

LIME = 'rgb(220, 243, 31)'
LIME_NUM = (128, 255, 128)

PINK = 'rgb(232, 124, 243)'
PINK_NUM = (255, 124, 243)

WHITE = 'rgb(255,255,255)'
WHITE_NUM = (255,255,255)

BLACK = 'rgb(0,0,0)'
BLACK_NUM = (0,0,0)

GREY = 'rgb(223, 210, 213)'
GREY_NUM = (192, 196, 199)
TRACE_COLORS = [TEAL_NUM, ORANGE_NUM, GREEN_NUM]

MARKER_HOVER = PINK_NUM